class Node:
        def __init__(self, data):
            self.data = data
            self.left = None
            self.right = None
        def printTree(self):
            if self.left:
                self.left.printTree()
            print(self.data),
            if self.right:
                self.right.printTree()
        def insert(self, data):

            if self.data:
                if data < self.data:
                    if self.left is None:
                        self.left = Node(data)
                    else:
                        self.left.insert(data)
                elif data > self.data:
                    if self.right is None:
                        self.right = Node(data)
                    else:
                        self.right.insert(data)
            else:
                self.data = data
        def findval(self, lkpval):
            if lkpval < self.data:
                if self.left is None:
                    return str(lkpval)+" Not Found"
                return self.left.findval(lkpval)
            elif lkpval > self.data:
                if self.right is None:
                    return str(lkpval)+" Not Found"
                return self.right.findval(lkpval)
            else:
                print(str(self.data) + ' is found')

class binary_tree:
    def __init__(self, values):
        self.tree = None
        if values:
            head = Node(values[0])
            for value in values:
                head.insert(value)
        self.tree = head
        print(self.tree)
   
        
    
                     
                        
            




from distutils.core import setup
setup(
  name = 'pydatastructures',         
  packages = ['pydatastructures'],   # Chose the same as "name"
  version = '0.2.1',      
  license='MIT',       
  description = 'This is a python library to implement data structures and algorithms',   
  author = 'Juan Pablo Montoya',                   
  author_email = 'A01251887@itesm.mx',      
  url = 'https://github.com/JuanPabloMontoya271/pydatastructures.git',   
  download_url = "https://github.com/JuanPabloMontoya271/pydatastructures/archive/v_02.1.tar.gz",

  keywords = ['python', 'data structures'],
  install_requires=[            # I get to this in a second
          'numpy'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
